FormBuilderState class

Implemented types

Constructors

FormBuilderState()

Properties

component FormBuilder
The current configuration.
no setterinherited
context → BuildContext
The location in the tree where this component builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isSubmitted bool
no setteroverride
isSubmitting bool
no setteroverride
isValid bool
no setteroverride
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, String>
no setteroverride
version int
no setteroverride

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
deactivate() → void
Called when this object is removed from the tree.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateComponent(covariant FormBuilder oldComponent) → void
Called whenever the component configuration changes.
dispose() → void
Called when this object is removed from the tree permanently.
inherited
field(String name) FieldState?
override
initState() → void
Called when this object is inserted into the tree.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerField(String name, {String initialValue = ''}) → void
override
reset() → void
override
setFieldError(String name, String? error) → void
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
shouldRebuild(covariant FormBuilder newComponent) bool
Implement this method to determine whether a rebuild can be skipped.
inherited
submit() Future<void>
override
toString() String
A string representation of this object.
inherited
unregisterField(String name) → void
override
updateField(String name, String newValue) → void
override
validate() bool
override

Operators

operator ==(Object other) bool
The equality operator.
inherited