MaxLength class

Constructors

MaxLength(int max, {String message = 'Must be at most {max} characters'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
max int
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String value) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited